package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallSchoolMaster;

/**
 * 学校硕士点Service接口
 * 
 * @author ruoyi
 * @date 2023-10-26
 */
public interface IMallSchoolMasterService 
{
    /**
     * 查询学校硕士点
     * 
     * @param masterId 学校硕士点主键
     * @return 学校硕士点
     */
    public MallSchoolMaster selectMallSchoolMasterByMasterId(Long masterId);

    /**
     * 查询学校硕士点列表
     * 
     * @param mallSchoolMaster 学校硕士点
     * @return 学校硕士点集合
     */
    public List<MallSchoolMaster> selectMallSchoolMasterList(MallSchoolMaster mallSchoolMaster);

    /**
     * 新增学校硕士点
     * 
     * @param mallSchoolMaster 学校硕士点
     * @return 结果
     */
    public int insertMallSchoolMaster(MallSchoolMaster mallSchoolMaster);

    /**
     * 修改学校硕士点
     * 
     * @param mallSchoolMaster 学校硕士点
     * @return 结果
     */
    public int updateMallSchoolMaster(MallSchoolMaster mallSchoolMaster);

    /**
     * 批量删除学校硕士点
     * 
     * @param masterIds 需要删除的学校硕士点主键集合
     * @return 结果
     */
    public int deleteMallSchoolMasterByMasterIds(Long[] masterIds);

    /**
     * 删除学校硕士点信息
     * 
     * @param masterId 学校硕士点主键
     * @return 结果
     */
    public int deleteMallSchoolMasterByMasterId(Long masterId);
}
